@@ -404,7 +404,7 @@ enumerate_eeg_channels() const
                                 for ( auto &E : D.second.episodes )
                                         for ( auto &F : E.sources )
                                                 for ( size_t h = 0; h < F().n_channels(); ++h )
-                                                        if ( F().signal_type(h) == sigfile::SChannel::TType::eeg )
+                                                        if ( F().signal_type(h) == sigfile::definitions::types::eeg )
                                                                 recp.push_back( F().channel_by_id(h));
         recp.sort();
         recp.unique();
@@ -433,7 +433,7 @@ enumerate_all_channels() const
 
 list<size_t>
 agh::CExpDesign::
-used_samplerates( sigfile::SChannel::TType type) const
+used_samplerates( sigfile::definitions::types type) const
 {
         list<size_t> recp;
         for ( auto &G : groups )
@@ -442,7 +442,7 @@ used_samplerates( sigfile::SChannel::TType type) const
                                 for ( auto &E : D.second.episodes )
                                         for ( auto &F : E.sources )
                                                 for ( size_t h = 0; h < F().n_channels(); ++h )
-                                                        if ( type == sigfile::SChannel::TType::other or
+                                                        if ( type == sigfile::definitions::types::invalid or
                                                              type == F().signal_type(h) ) {
                                                                 recp.push_back( F().samplerate(h));
                                                         }
@@ -612,10 +612,3 @@ purge_cached_profiles()
                         session_dir())
                 .c_str());
 }
-
-// Local Variables:
-// Mode: c++
-// indent-tabs-mode: nil
-// tab-width: 8
-// c-basic-offset: 8
-// End:
