@@ -146,7 +146,8 @@ daSubjectTimeline_scroll_event_cb(
                 default: break;
                 }
 
-                ED.tl_width = (ED.timeline_end - ED.timeline_start) / 3600 * ED.tl_pph;
+                auto hours = (ED.timeline_end - ED.timeline_start) / 3600;
+                ED.tl_width = (hours < 1 ? 1 : hours) * ED.tl_pph;
                 for ( auto &G : ED.groups )
                         for ( auto &J : G )
                                 g_object_set(
@@ -296,10 +297,3 @@ iSubjectTimelineResetMontage_activate_cb(
 
 
 } // extern "C"
-
-// Local Variables:
-// Mode: c++
-// indent-tabs-mode: nil
-// tab-width: 8
-// c-basic-offset: 8
-// End:
