@@ -53,7 +53,7 @@ populate( bool do_load)
         used_samplerates =
                 ED->used_samplerates();
         used_eeg_samplerates =
-                ED->used_samplerates( sigfile::SChannel::TType::eeg);
+                ED->used_samplerates( sigfile::definitions::types::eeg);
         if ( used_eeg_samplerates.size() == 1 )
                 APPLOG_INFO ("single common EEG samplerate: %zu", used_eeg_samplerates.front());
         else {
@@ -246,7 +246,7 @@ populate_mChannels()
                 GtkTreeIter iter;
                 gtk_list_store_append( mEEGChannels, &iter);
                 gtk_list_store_set( mEEGChannels, &iter,
-                                    0, H.name(),
+                                    0, H.custom_name(),
                                     -1);
         }
 
@@ -254,7 +254,7 @@ populate_mChannels()
                 GtkTreeIter iter;
                 gtk_list_store_append( mAllChannels, &iter);
                 gtk_list_store_set( mAllChannels, &iter,
-                                    0, H.name(),
+                                    0, H.custom_name(),
                                     -1);
         }
 
@@ -413,7 +413,7 @@ populate_1()
 
         APPLOG_INFO ("populate_1(): session \"%s\", channel \"%s\"", AghD(), AghT());
 
-        time_t        earliest_start = (time_t)-1,
+        time_t  earliest_start = (time_t)-1,
                 latest_end = (time_t)-1;
       // first pass: (1) create SSubjectPresentation's
       //             (2) determine common timeline
@@ -435,8 +435,8 @@ populate_1()
 
                                         j.admission_date = ee.front().start_time();
                                 } else
-                                        fprintf( stderr, "SExpDesignUI::populate_1(): session \"%s\", channel \"%s\" for subject \"%s\" is empty\n",
-                                                 AghD(), AghT(), J.id.c_str());
+                                        APPLOG_WARN ("SExpDesignUI::populate_1(): session \"%s\", channel \"%s\" for subject \"%s\" is empty\n",
+                                                     AghD(), AghT(), J.id.c_str());
                         }
                 }
         }
@@ -445,10 +445,14 @@ populate_1()
 
         timeline_start = earliest_start;
         timeline_end   = latest_end;
-        tl_width = (timeline_end - timeline_start) / 3600 * tl_pph;
-        tl_pages = (timeline_end - timeline_start) / ED->psd_params.pagesize;
+        decltype(timeline_end) full_secs =
+                timeline_end - timeline_start;
+        if ( full_secs < 3600 )
+                full_secs = 3600;
+        tl_width = full_secs * tl_pph;
+        tl_pages = full_secs / ED->psd_params.pagesize;
 
-        APPLOG_INFO ("populate_1(): common timeline:");
+        APPLOG_INFO ("populate_1(): common timeline is %zu pages:", tl_pages);
         {
                 string t {asctime( localtime(&earliest_start))};
                 t += asctime( localtime(&latest_end));
@@ -649,10 +653,3 @@ operator<( const SSubjectPresentation& rv) const
 
         return result;
 }
-
-// Local Variables:
-// Mode: c++
-// indent-tabs-mode: nil
-// tab-width: 8
-// c-basic-offset: 8
-// End:
