@@ -112,30 +112,30 @@ SScoringFacility (agh::CSubject& J,
                 size_t  y = interchannel_gap / 2.;
                 int     seq = 1;
                 for ( auto &H : _sepisode.recordings )
-                        if ( H.second.signal_type() == sigfile::SChannel::TType::eeg ) {
-                                _p.sb_message( snprintf_buf( "Reading and processing EEG channel %s ...", H.first.c_str()));
+                        if ( H.second.signal_type() == sigfile::definitions::types::eeg ) {
+                                _p.sb_message( snprintf_buf( "Reading and processing EEG channel %s ...", H.first.custom_name()));
                                 channels.emplace_back( H.second, *this, y, seq++);
                                 y += interchannel_gap;
                         }
                 for ( auto &H : _sepisode.recordings )
-                        if ( H.second.signal_type() == sigfile::SChannel::TType::eog ) {
-                                _p.sb_message( snprintf_buf( "Reading and processing EOG channel %s ...", H.first.c_str()));
+                        if ( H.second.signal_type() == sigfile::definitions::types::eog ) {
+                                _p.sb_message( snprintf_buf( "Reading and processing EOG channel %s ...", H.first.custom_name()));
                                 channels.emplace_back( H.second, *this, y, seq++);
                                 y += interchannel_gap;
                         }
                 for ( auto &H : _sepisode.recordings )
-                        if ( H.second.signal_type() == sigfile::SChannel::TType::emg ) {
-                                _p.sb_message( snprintf_buf( "Reading and processing EMG channel %s ...", H.first.c_str()));
+                        if ( H.second.signal_type() == sigfile::definitions::types::emg ) {
+                                _p.sb_message( snprintf_buf( "Reading and processing EMG channel %s ...", H.first.custom_name()));
                                 channels.emplace_back( H.second, *this, y, seq++);
                                 y += interchannel_gap;
                         }
                 for ( auto &H : _sepisode.recordings ) {
                         auto type = H.second.signal_type();
-                        if ( type != sigfile::SChannel::TType::eeg &&
-                             type != sigfile::SChannel::TType::eog &&
-                             type != sigfile::SChannel::TType::emg &&
-                             type != sigfile::SChannel::TType::embedded_annotation ) {
-                                _p.sb_message( snprintf_buf( "Reading and processing channel %s ...", H.first.c_str()));
+                        if ( type != sigfile::definitions::types::eeg &&
+                             type != sigfile::definitions::types::eog &&
+                             type != sigfile::definitions::types::emg &&
+                             type != sigfile::definitions::types::edf_annotation ) {
+                                _p.sb_message( snprintf_buf( "Reading and processing channel %s ...", H.first.custom_name()));
                                 channels.emplace_back( H.second, *this, y, seq++);
                                 y += interchannel_gap;
                         }
@@ -162,7 +162,7 @@ SScoringFacility (agh::CSubject& J,
         n_eeg_channels =
                 count_if( channels.begin(), channels.end(),
                           [] (const SChannel& h)
-                          { return h.type() == sigfile::SChannel::TType::eeg; });
+                          { return h.type() == sigfile::definitions::types::eeg; });
 
       // load montage, recalibrate display scales as necessary
         load_montage();
@@ -184,7 +184,7 @@ SScoringFacility (agh::CSubject& J,
                                         interchannel_gap / 2);
                 agh::alg::ensure_within( h.signal_display_scale, scale_min, scale_max);
 
-                if ( h.type() == sigfile::SChannel::TType::eeg ) {
+                if ( h.type() == sigfile::definitions::types::eeg ) {
                       // calibrate profile display scales
                         if ( not sane_scale(h.psd.display_scale) )
                                 h.psd.display_scale =
@@ -530,7 +530,7 @@ set_cur_vpage( size_t p, const bool touch_self)
         if ( ap2p(p) != _cur_page ) { // vpage changed but page is same
                 _cur_page = ap2p(p);
                 for ( auto& H : channels )
-                        if ( H.type() == sigfile::SChannel::TType::eeg && H.draw_spectrum )
+                        if ( H.type() == sigfile::definitions::types::eeg && H.draw_spectrum )
                                 H.get_spectrum( _cur_page);
 
                 gtk_widget_set_sensitive( (GtkWidget*)bSFForward, _cur_vpage < total_vpages()-1);
@@ -756,9 +756,9 @@ load_montage()
                 h.selection_end = h.selection_end_time * h.samplerate();
 
               // make sure these won't cause any confusion later
-                if ( h.type() == sigfile::SChannel::TType::eeg )
+                if ( h.type() == sigfile::definitions::types::eeg )
                         h.draw_emg = false;
-                if ( h.type() == sigfile::SChannel::TType::emg )
+                if ( h.type() == sigfile::definitions::types::emg )
                         h.draw_psd = h.draw_swu = h.draw_mc = false;
         }
 
@@ -889,12 +889,3 @@ update_main_menu_items()
 
         suppress_redraw = false;
 }
-
-
-
-// Local Variables:
-// Mode: c++
-// indent-tabs-mode: nil
-// tab-width: 8
-// c-basic-offset: 8
-// End:
